.. _ref_logging_guide:

Logging
=======

PyFluent uses the logging API provided by the Python standard library. You can
find out more about `Python logging here <https://www.python.org/downloads/>`_.
PyFluent provides multiple loggers and packages a logging_config.yaml in the standard
format which you can edit to configure logging according to your requirements.
